function d = spd_sigma2diam(sigma,lambda)

%Particle diameter, given radar cross section, using Rayleigh's formula
%D = SPD_SIGMA2DIAM(SIGMA,LAMBDA)
%
%   SIGMA in square meters, LAMBDA in meters. Then D is in meters.
% 
%   We use the formula as simplified by Asko H, by taking the cross section
%   equal to geom cross section  for all diam greater than lambda/pi/sqrt(3).
%   See WP-1 report.
%
%   See also SPD_DIAM2SIGMA.
%       
% 5-Jul-2001 Jm 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if length(sigma) == 1
    if sigma < lambda^2/(12*pi)
        d = ( 4 * lambda^4 * sigma / (9 * pi^5) ) ^ (1/6);
    else
        d = 2 * sqrt(sigma/pi);
    end
else
    K = find( sigma < lambda^2/(12*pi) );
    d = zeros(size(sigma));
    d(K) = ( 4 * lambda^4 * sigma(K) / (9 * pi^5) ) .^ (1/6);
    N = 1:length(d);
    N(K) = [];
    d(N) = 2 * sqrt(sigma(N)/pi);
end
return
